@@ -38,10 +38,10 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_version =
-        "25.0.2-beta";
+        "25-beta";
 
     private static final String java_version_date =
-        "2026-01-20";
+        "2025-09-16";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -49,16 +49,16 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "25.0.2-beta+10-ea";
+        "25-beta+30-ea";
 
     private static final String VERSION_NUMBER =
-        "25.0.2";
+        "25";
 
     private static final String VERSION_SPECIFICATION =
         "25";
 
     private static final String VERSION_BUILD =
-        "10";
+        "30";
 
     private static final String VERSION_PRE =
         "beta";
@@ -83,7 +83,7 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static String VENDOR_VERSION =
-        "Temurin-25.0.2+10-202601222215";
+        "Temurin-25+30-202507052035";
 
     private static String VENDOR_URL_BUG =
         "https://github.com/adoptium/adoptium-support/issues";
